#!/bin/sh
#
#

[ -z "$MILTER_SOCKDIR" ] && MILTER_SOCKDIR=/var/spool/postfix/benno-milter

case "$1" in
    remove)
        #
        # Remove socket directory in Postfix chroot environment
        #
        set +e
        [ -d "$MILTER_SOCKDIR" ] && rmdir --ignore-fail-on-non-empty "$MILTER_SOCKDIR"
        set -e
    ;;
    purge)
        # ignore errors during purge

    ;;
esac
